@@ -3,21 +3,13 @@
 import py_compile
 import os
 
-if os.path.exists("/opt/barriosquare/oauth.py"):
-	os.remove("/opt/barriosquare/oauth.py")
-	
-if os.path.exists("/opt/barriosquare/oauth.pyc"):
-	os.remove("/opt/barriosquare/oauth.pyc")	
-
 py_compile.compile("/opt/barriosquare/barriosq.py")
 py_compile.compile("/opt/barriosquare/barriodata.py")
+py_compile.compile("/opt/barriosquare/barriotime.py")
 py_compile.compile("/opt/barriosquare/bootstrap.py")
 py_compile.compile("/opt/barriosquare/barrioConfig.py")
 py_compile.compile("/opt/barriosquare/barrioStyles.py")
 py_compile.compile("/opt/barriosquare/oauthlib.py")
 py_compile.compile("/opt/barriosquare/oauthclient.py")
 py_compile.compile("/opt/barriosquare/get-location.py")
-py_compile.compile("/opt/barriosquare/oauthtwitter/__init__.py")
-py_compile.compile("/opt/barriosquare/oauthtwitter/oauthtwitter.py")
-py_compile.compile("/opt/barriosquare/oauthtwitter/oauth/__init__.py")
-py_compile.compile("/opt/barriosquare/oauthtwitter/oauth/oauth.py")
\ No newline at end of file
+py_compile.compile("/opt/barriosquare/foursquare.py")
